summaryrefslogtreecommitdiffstats
path: root/src/replaygain.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-01-24 13:26:51 -0600
committerTimothy Pearson <[email protected]>2013-01-24 13:26:51 -0600
commitbece9aa3ad05fe774bf89d9a840235ee8adfd4da (patch)
treebd2dbbe6c3a6ea126e93209798a088ffe78d1783 /src/replaygain.h
parent5e21b1fe4b7ac01e6a2cbdf230ad830c924f7be3 (diff)
downloadsoundkonverter-bece9aa3ad05fe774bf89d9a840235ee8adfd4da.tar.gz
soundkonverter-bece9aa3ad05fe774bf89d9a840235ee8adfd4da.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'src/replaygain.h')
-rwxr-xr-xsrc/replaygain.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/replaygain.h b/src/replaygain.h
index d844ae7..53fd6e8 100755
--- a/src/replaygain.h
+++ b/src/replaygain.h
@@ -8,7 +8,7 @@
class Config;
class Logger;
-class KProcess;
+class TDEProcess;
/**
* @short Starts a process to add/remove Replay Gain tags to/from a given file
@@ -41,10 +41,10 @@ public:
* Add/remove Replay Gain
* @param files a list of files (of the same format)
* @param format the format of the file/files (extension or mime type)
* @param prc a pointer to a KProcess
* @param remove if true the Replay Gain tags are being removed, if false (default) the tags are calculated and added
*/
- bool apply( TQStringList files, const TQString& format, KProcess* proc, int logID, Mode mode = Mode(calc_track|calc_album) ); // NOTE const TQStringList& ?
+ bool apply( TQStringList files, const TQString& format, TDEProcess* proc, int logID, Mode mode = Mode(calc_track|calc_album) ); // NOTE const TQStringList& ?
/*
* Returns the track and the album gain (in this order) of the @p file
@@ -41,10 +41,10 @@ public:
* @param files a list of files (of the same format)
* @param format the format of the file/files (extension or mime type)
- * @param prc a pointer to a KProcess
+ * @param prc a pointer to a TDEProcess
* @param remove if true the Replay Gain tags are being removed, if false (default) the tags are calculated and added
*/